@@ -61,14 +61,12 @@
 (define (sizeof-string-const value)
   #f)
 
-(include-from-path "nyacc/lang/c99/mach.d/c99cxtab.scm")
-(include-from-path "nyacc/lang/c99/mach.d/c99cxact.scm")
+(include-from-path "nyacc/lang/c99/mach.d/c99cx-act.scm")
+(include-from-path "nyacc/lang/c99/mach.d/c99cx-tab.scm")
 
 (define c99cx-raw-parser
   (make-lalr-parser
-   (list (cons 'len-v c99cx-len-v) (cons 'pat-v c99cx-pat-v)
-	 (cons 'rto-v c99cx-rto-v) (cons 'mtab c99cx-mtab)
-	 (cons 'act-v c99cx-act-v))))
+   (acons 'act-v c99cx-act-v c99cx-tables)))
 
 (define gen-c99cx-lexer
   (let* ((reader (make-comm-reader '(("/*" . "*/"))))
@@ -153,6 +151,7 @@
 ;; Evaluate the constant expression or return #f
 ;; @end deffn
 (define* (eval-c99-cx tree #:optional udict ddict)
+  (define (fail) #f)
   (letrec
       ((ev (lambda (ex ix) (eval-expr (sx-ref ex ix))))
        (ev1 (lambda (ex) (ev ex 1)))	; eval expr in arg 1
@@ -208,14 +207,13 @@
 	    ((fctn-call) #f)		; assume not constant
 	    ;;
 	    ;; TODO 
-	    ((comp-lit) #f) ;; return a bytearray
-	    ((comma-expr) #f)
-	    ((i-sel) #f)
-	    ((d-sel) #f)
-	    ((array-ref) #f)
+	    ((comp-lit) (fail))		; return a bytearray
+	    ((comma-expr) (fail))
+	    ((i-sel) (fail))
+	    ((d-sel) (fail))
+	    ((array-ref) (fail))
 	    ;; 
-	    (else
-	     (throw 'c99-error "eval-c99-cx: missed ~S" (car tree)))))))
+	    (else (fail))))))
     (eval-expr tree)))
 
 ;; --- last line ---
