@@ -92,7 +92,7 @@
   #:use-module (ice-9 regex)
   #:use-module (ice-9 pretty-print)
   #:re-export (*nyacc-version*)
-  #:version (0 99 1))
+  #:version (0 99 3))
 
 (define fh-cpp-defs
   (cond
@@ -245,6 +245,7 @@
    (lambda (s l)
      (cond 
       ((< (string-length s) 3) l)
+      ((string=? "-lm" s) l) ;; workaround for ubuntu libm issue
       ((string=? "-l" (substring/shared s 0 2))
        (cons (string-append "lib" (substring/shared s 2)) l))
       (else l)))
@@ -298,7 +299,8 @@
 	 (libraries (resolve-attr-val (assq-ref attrs 'library)))
 	 (libraries (append
 		     (if pkg-config (pkg-config-libs pkg-config) '())
-		     libraries)))
+		     libraries))
+ 	 (libraries (delete "libm" libraries))) ;; workaround for ubuntu
     (sfscm ";; generated with `guild compile-ffi ~A.ffi'\n" (path->path path))
     (nlscm)
     (sfscm "(define-module ~S\n" path)
@@ -321,7 +323,6 @@
     (ppscm
      `(define ,(link-libs)
 	(list ,@(map (lambda (l) `(dynamic-link ,l)) (reverse libraries)))))
-    ;;(sfscm "(define link-lib (car link-libs))\n")
     (if (*echo-decls*) (sfscm "(define echo-decls #t)\n"))))
 
 ;; === type conversion ==============
@@ -364,8 +365,7 @@
     ;; hacks:
     ("char" . int8) ("signed char" . int8) ("unsigned char" . uint8)
     ("wchar_t" . int) ("char16_t" . int16) ("char32_t" . int32)
-    ("_Bool" . int8)
-    ))
+    ("_Bool" . int8)))
 
 (define bs-defined (map car bs-typemap))
 
@@ -550,8 +550,7 @@
     (ppscm `(define-fh-function*-type ,sy-name
 	      ,(string->symbol (string-append name "-desc"))
 	      ,(string->symbol (string-append name "?"))
-	      ,(string->symbol (string-append "make-" name))
-	      ))
+	      ,(string->symbol (string-append "make-" name))))
     (fhscm-export-def name)))
 
 (define* (fhscm-def-fixed name)
@@ -700,8 +699,7 @@
      ((and typename enum-name)
       (fhscm-def-enum typename name-val-l)
       (sfscm "(define-public unwrap-enum-~A unwrap-~A)\n" enum-name typename)
-      (sfscm "(define-public wrap-enum-~A wrap-~A)\n" enum-name typename)
-      )
+      (sfscm "(define-public wrap-enum-~A wrap-~A)\n" enum-name typename))
      (typename
       (fhscm-def-enum typename name-val-l))
      (enum-name
@@ -1066,8 +1064,7 @@
 	 ;;(call `(,~name ,@(gen-exec-call-args exec-params)))
 	 (va-call `(apply ,~name ,@(gen-exec-call-args exec-params)
 			  (map cdr ~rest)))
-	 (call `((force ,~name) ,@(gen-exec-call-args exec-params)))
-	 )
+	 (call `((force ,~name) ,@(gen-exec-call-args exec-params))))
     (cond
      (varargs?
       (sfscm ";; to be used with fh-cast\n")
@@ -1095,8 +1092,7 @@
 				      ,(link-libs)))))
 	    (lambda ,(gen-exec-arg-names exec-params)
 	      (let ,(gen-exec-unwrappers exec-params)
-		,(if exec-return (list exec-return call) call))))))
-      ))
+		,(if exec-return (list exec-return call) call))))))))
     (sfscm "(export ~A)\n" name)))
 
 ;; === externs ========================
@@ -1391,8 +1387,7 @@
 	   (sfscm "(define-public ~A? fh-void?)\n" typename)
 	   (sfscm "(define-public make-~A make-fh-void)\n" typename)
 	   (sfscm "(define-public ~A*-desc (bs:pointer (delay ~A-desc)))\n"
-		  typename typename)
-	   ))
+		  typename typename)))
 	(else
 	 ;; 3) struct never defined; only used as pointer
 	 (sfscm "(define-public ~A-desc 'void)\n" typename)
@@ -1522,8 +1517,7 @@
        (let* ((ret-decl `(udecl (decl-spec-list . ,rst)
 				(init-declr (ident "_"))))
 	      (decl-return (gen-bs-decl-return ret-decl))
-	      (decl-params (gen-bs-decl-params params))
-	      )
+	      (decl-params (gen-bs-decl-params params)))
 	 (fhscm-def-function* typename decl-return decl-params))
        (values (cons typename wrapped) (cons typename defined)))
 
@@ -1541,8 +1535,7 @@
 	      ;;(decl-return (gen-decl-return ret-decl))
 	      ;;(decl-params (gen-decl-params params))
 	      (decl-return (gen-decl-return ret-decl))
-	      (decl-params (gen-decl-params params))
-	      )
+	      (decl-params (gen-decl-params params)))
 	 (fhscm-def-function* typename decl-return decl-params))
        (values (cons typename wrapped) (cons typename defined)))
 
@@ -1763,8 +1756,7 @@
 		 (decl-spec-list (type-spec (typename "haddr_t")))))
 	       (p-expr (fixed "4"))))))
        (let* ((typename "haddr_t")
-	      (size (+ (sizeof '*) 4))
-	      )
+	      (size (+ (sizeof '*) 4)))
 	 (sfscm "(define-public ~A-desc (bs:vector ~A '*))\n" typename size)
 	 ;;(sfscm "(define-fh-compound-type/p ~A ~A-desc)\n" typename typename)
 	 (fhscm-def-compound typename)
@@ -2060,8 +2052,7 @@
 		    (vname (string->symbol (string-append pname "-types")))
 		    (var (module-ref modul vname)))
 	       (append var seed)))
-	   '() ext-mods))
-	 )
+	   '() ext-mods)))
     ;; set globals
     (*prefix* (path->name path))
     (*udict* udict)
@@ -2195,8 +2186,7 @@
 	   (scmport (mkstemp! (string-copy ",_FH_XXXXXX")))
 	   ;;(scmport (tmpfile)) ;; does not work ?
 	   (scmfile (port-filename scmport))
-	   (compile-file (@@ (system base compile) compile-file))
-	   )
+	   (compile-file (@@ (system base compile) compile-file)))
       (*prefix* (symbol->string (gensym "fh-")))
       (*mport* scmport)
       (*udict* udict)
