@@ -69,8 +69,7 @@
 	    ;; debugging
 	    stripdown-1
 	    tdef-splice-specl
-	    tdef-splice-declr
-	    )
+	    tdef-splice-declr)
   #:use-module ((nyacc lang c99 cpp) #:select (eval-cpp-expr))
   #:use-module (nyacc lang c99 cxeval) ;; eval-c99-cx
   #:use-module (nyacc lang c99 pprint)
@@ -85,8 +84,7 @@
   #:use-module (system base pmatch)
   ;; debugging:
   #:use-module (system vm trace)
-  #:use-module (ice-9 pretty-print)
-  )
+  #:use-module (ice-9 pretty-print))
 ;; undocumented Guile builtins: or-map
 
 (define (sferr fmt . args) (apply simple-format (current-error-port) fmt args))
@@ -369,7 +367,7 @@
   ;;(simple-format #t "unitize-decl ~S\n" decl)
   (cond
    ((not (pair? decl))
-    (error "bad arg"))
+    (throw 'nyacc-error "unitize-decl: bad arg: ~S" decl))
    ((eqv? (sx-tag decl) 'udecl)
     (acons (udecl-id decl) decl seed))
 
@@ -488,7 +486,7 @@
 (define* (unitize-comp-decl decl #:optional (seed '()))
   (cond
    ((not (pair? decl))
-    (error "bad arg"))
+    (throw 'nyacc-error "unitize-decl: bad arg: ~S" decl))
    ((eqv? (sx-tag decl) 'comp-udecl)
     (acons (udecl-id decl) decl seed))
    ((eqv? (sx-tag (sx-ref decl 2)) 'comp-declr-list)
@@ -1003,7 +1001,7 @@
 ;; New option: #:skip-fdefs to skip function defs
 ;; @end deffn
 (define* (c99-trans-unit->ddict tree
-				#:optional (seed '())
+				#:optional (ddict '())
 				#:key inc-filter skip-fdefs)
   (define (can-def-stmt defn)
     (let* ((tail (sx-tail defn 1))
@@ -1014,26 +1012,25 @@
   (define (cpp-def? tree)
     (if (and (eq? 'cpp-stmt (sx-tag tree))
 	     (eq? 'define (sx-tag (sx-ref tree 1)))
-	     (not (and skip-fdefs (assq 'args (sx-tail (sx-ref tree 1) 1))))
-	     )
+	     (not (and skip-fdefs (assq 'args (sx-tail (sx-ref tree 1) 1)))))
 	(can-def-stmt (sx-ref tree 1))
 	#f))
   (if (pair? tree)
       (fold
-       (lambda (tree seed)
+       (lambda (tree ddict)
 	 (cond
 	  ((cpp-def? tree) =>
 	   (lambda (def-stmt)
-	     (cons def-stmt seed)))
+	     (cons def-stmt ddict)))
 	  ((inc-keeper? tree inc-filter) =>
 	   (lambda (tree)
-	     (c99-trans-unit->ddict tree seed #:inc-filter inc-filter)))
-	  (else seed)))
-       seed
+	     (c99-trans-unit->ddict tree ddict #:inc-filter inc-filter)))
+	  (else ddict)))
+       ddict
        (cdr tree))
-      seed))
+      ddict))
 
-;; @deffn {Procedure} udict-enums->ddict [seed] => defs
+;; @deffn {Procedure} udict-enums->ddict udict [ddict] => defs
 ;; Given a udict this generates a list that looke like the internal
 ;; CPP define structure.  That is,
 ;; @example
@@ -1044,32 +1041,32 @@
 ;; @example
 ;; (("ABC" . "0") ...)
 ;; @end example
-;; This procedure expects @var{udict} to be in reverse order wrt the source
-;; input (i.e., as output from @code{c99-trans-unit->udecl}) and generate
-;; symbols in revers order wrt the output;
 ;; @end deffn
-(define* (udict-enums->ddict udict #:optional (seed '()))
-  (define (gen-nvl enum-def-list seed)
-    (fold
-     (lambda (edef seed) ;; (enum-def (ident ,name) (fixed ,val) ...
-       (acons (sx-ref* edef 1 1) (sx-ref* edef 2 1) seed))
-     seed (cdr (canize-enum-def-list enum-def-list seed))))
-  (fold-right
-   (lambda (pair seed)
+(define* (udict-enums->ddict udict #:optional (ddict '()))
+  (define (gen-nvl enum-def-list ddict)
+    (let ((def-list (and=> (canize-enum-def-list enum-def-list ddict udict)
+			   cdr)))
+    (fold (lambda (edef ddict) ;; (enum-def (ident ,name) (fixed ,val) ...
+	    (acons (sx-ref* edef 1 1) (sx-ref* edef 2 1) ddict))
+	  ddict def-list)))
+  (fold
+   (lambda (pair ddict)
      (if (and (pair? (car pair)) (eq? 'enum (caar pair)))
 	 ;; (enum . ,name) ...
 	 (let* ((specl (sx-ref (cdr pair) 1))
 		(tspec (car (assq-ref specl 'type-spec))))
-	   (if (not (eq? 'enum-def (car tspec))) (error "expecting enum-def"))
-	   (gen-nvl (assq 'enum-def-list (cdr tspec)) seed))
+	   (if (not (eq? 'enum-def (car tspec)))
+	       (throw 'nyacc-error "udict-enums->ddict: expecting enum-def"))
+	   (gen-nvl (assq 'enum-def-list (cdr tspec)) ddict))
 	 ;; else ...
-	 seed))
-   seed udict))
+	 ddict))
+   ddict udict))
 
 
 ;; === enum handling ===================
 
-;; @deffn {Procedure} canize-enum-def-list enum-def-list [defs] => enum-def-list
+;; @deffn {Procedure} canize-enum-def-list enum-def-list [ddict] [udict] \
+;;      => enum-def-list
 ;; Fill in constants for all entries of an enum list.
 ;; Expects @code{(enum-def-list (...))} (i.e., not the tail).
 ;; All enum-defs will have the form like @code{(fixed "1")}.
@@ -1080,10 +1077,11 @@
 ;; (enum-def-list (enum-def (ident "FOO") (fixed "0") ...))
 ;; @end example
 ;; @noindent
-;; Note: Does this really need to be @code{(p-expr (fixed "0"))}?
 ;; @end deffn
-(define* (canize-enum-def-list enum-def-list #:optional (ddict '()))
-  (let loop ((rez '()) (nxt 0) (dct ddict) (edl (sx-tail enum-def-list 1)))
+(define* (canize-enum-def-list enum-def-list #:optional (ddict '()) (udict '()))
+  (define (fail ident)
+    (sferr "*** failed to convert enum ~S to constant" (sx-ref ident 1)) #f)
+  (let loop ((rez '()) (nxt 0) (ddict ddict) (edl (sx-tail enum-def-list 1)))
     (cond
      ((null? edl)
       (sx-cons* (sx-tag enum-def-list) (sx-attr enum-def-list) (reverse rez)))
@@ -1092,22 +1090,21 @@
 	((enum-defn (@ . ,attr) ,ident)
 	 (let ((sval (number->string nxt)))
 	   (loop (cons (sx-list 'enum-defn attr ident `(fixed ,sval)) rez)
-		 (1+ nxt)  (acons (sx-ref ident 1) sval dct) (cdr edl))))
-	((enum-defn ,ident (comment ,comm)) ;; REMOVE
+		 (1+ nxt)  (acons (sx-ref ident 1) sval ddict) (cdr edl))))
+	((enum-defn ,ident)
 	 (let ((sval (number->string nxt)))
-	   (loop (cons `(enum-defn ,ident (fixed ,sval) (comment ,comm)) rez)
-		 (1+ nxt) (acons (sx-ref ident 1) sval dct) (cdr edl))))
+	   (loop (cons (sx-list 'enum-defn #f ident `(fixed ,sval)) rez)
+		 (1+ nxt)  (acons (sx-ref ident 1) sval ddict) (cdr edl))))
 	((enum-defn (@ . attr) ,ident ,expr)
-	 (let* ((ival (eval-cpp-expr expr dct))
-		(sval (number->string ival)))
+	 (let* ((ival (or (eval-c99-cx expr udict ddict) (fail ident) nxt))
+		(sval (number->string iv)))
 	   (loop (cons (sx-list 'enum-defn attr ident `(fixed ,sval)) rez)
-		 (1+ ival) (acons (sx-ref ident 1) sval dct) (cdr edl))))
-	((enum-defn ,ident ,expr . ,rest) ;; REMOVE
-	 (let* ((ival (eval-cpp-expr expr dct))
+		 (1+ ival) (acons (sx-ref ident 1) sval ddict) (cdr edl))))
+	((enum-defn ,ident ,expr)
+	 (let* ((ival (or (eval-c99-cx expr udict ddict) (fail ident) nxt))
 		(sval (number->string ival)))
-	   (loop (cons `(enum-defn ,ident (fixed ,sval) . ,rest) rez)
-		 (1+ ival) (acons (sx-ref ident 1) sval dct) (cdr edl))))
-	)))))
+	   (loop (cons (sx-list 'enum-defn #f ident `(fixed ,sval)) rez)
+		 (1+ ival) (acons (sx-ref ident 1) sval ddict) (cdr edl)))))))))
 
 ;; @deffn {Procecure} enum-ref enum-def-list name => string
 ;; Gets value of enum where @var{enum-def-list} looks like
@@ -1207,7 +1204,8 @@
 (define (specl-tail-rem-type-qual specl-tail)
   (remove (lambda (elt) (eq? 'type-qual (car elt))) specl-tail))
 (define (specl-rem-type-qual specl)
-  (if (not (eq? (sx-tag specl) 'decl-spec-list)) (error "expecting specl"))
+  (if (not (eq? (sx-tag specl) 'decl-spec-list))
+      (throw 'nyacc-error "expecting specl"))
   (sx-cons* (sx-tag specl) (sx-attr specl)
 	    (specl-tail-rem-type-qual (sx-tail specl 1))))
 (define (udecl-rem-type-qual udecl)
@@ -1270,7 +1268,8 @@
 		    ((null? cl) decl)
 		    (else (sx-attr-add decl 'comment (str-app-rev cl))))))
 	     (loop (cons decl rz) '() (cdr fl))))
-	  (,_ (error "munge: clean-field-list" (car fl)))))))
+	  (,_ (throw 'nyacc-error "clean-field-list: ~S" (car fl)))))))
+
 (define (clean-field-list field-list)
   (cons (car field-list) (clean-fields (cdr field-list))))
 
@@ -1299,8 +1298,7 @@
   ;; on constant expression eval (eval-c99-cx) maybe we should change that.
   (define (cnvt-size-expr size-spec)
     ;;(with-output-to-string (lambda () (pretty-print-c99 size-spec)))
-    size-spec
-    )
+    size-spec)
 
   (define (unwrap-specl specl)
     (and=> (assq-ref (sx-tail specl) 'type-spec) car))
@@ -1315,7 +1313,7 @@
       ((pointer) '((pointer-to)))
       (else
        (sferr "unwrap-pointer failed on:\n") (pperr pointer)
-       (error "unwrap-pointer"))))
+       (throw 'nyacc-error "unwrap-pointer"))))
 
   (define (make-abs-dummy) ;; for abstract declarator make a dummy
     (or add-name (symbol->string (gensym "@"))))
@@ -1386,7 +1384,7 @@
       (else
        (sferr "munge/unwrap-declr missed:\n")
        (pperr declr)
-       (error "c99/munge: udecl->mdecl failed")
+       (throw 'nyacc-error "c99/munge: udecl->mdecl failed")
        #f)))
 
   ;;(sferr "decl:\n") (pperr decl)
@@ -1433,7 +1431,7 @@
       (,_
        (sferr "munge/mdecl->udecl missed:\n")
        (pperr mdecl-tail)
-       (error "munge/mdecl->udecl failed")
+       (throw 'nyacc-error "munge/mdecl->udecl failed")
        #f)))
 
   (let ((name (car mdecl))
